@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"io/ioutil"
 	"os"
+	"runtime"
 	"strings"
 	"sync"
 	"time"
@@ -43,6 +44,8 @@ import (
 
 const (
 	x86OCPContentRootDir = "/opt/openshift/operator/ocp-x86_64"
+	ppcOCPContentRootDir = "/opt/openshift/operator/ocp-ppc64le"
+	zOCPContentRootDir   = "/opt/openshift/operator/ocp-s390x"
 	installtypekey       = "keyForInstallTypeField"
 	regkey               = "keyForSamplesRegistryField"
 	skippedstreamskey    = "keyForSkippedImageStreamsField"
@@ -93,6 +96,8 @@ func NewSamplesOperatorHandler(kubeconfig *restclient.Config,
 	h.imagestreamFile = make(map[string]string)
 	h.templateFile = make(map[string]string)
 
+	h.imagestreamRetry = make(map[string]metav1.Time)
+
 	h.mapsMutex = sync.Mutex{}
 	h.version = os.Getenv("RELEASE_VERSION")
 
@@ -131,6 +136,8 @@ type Handler struct {
 	imagestreamFile map[string]string
 	templateFile    map[string]string
 
+	imagestreamRetry map[string]metav1.Time
+
 	mapsMutex sync.Mutex
 
 	upsertInProgress bool
@@ -267,6 +274,25 @@ func IsRetryableAPIError(err error) bool {
 	return false
 }
 
+// this method assumes it is only called on initial cfg create, or if the Architecture array len == 0
+func (h *Handler) updateCfgArch(cfg *v1.Config) *v1.Config {
+	switch {
+	// if you look at https://golang.org/dl/ the arch symbols for ppc and 390 container
+	// the values of our constants below.
+	case strings.Contains(runtime.GOARCH, v1.PPCArchitecture):
+		cfg.Spec.Architectures = append(cfg.Spec.Architectures, v1.PPCArchitecture)
+	case strings.Contains(runtime.GOARCH, v1.S390Architecture):
+		cfg.Spec.Architectures = append(cfg.Spec.Architectures, v1.S390Architecture)
+	case strings.Contains(runtime.GOARCH, v1.AMDArchitecture):
+		fallthrough
+	case strings.Contains(runtime.GOARCH, v1.X86Architecture):
+		cfg.Spec.Architectures = append(cfg.Spec.Architectures, v1.X86Architecture)
+	default:
+		logrus.Warningf("unsupported hardware architecture indicated by the golang GOARCH variable being set to %s", runtime.GOARCH)
+	}
+	return cfg
+}
+
 func (h *Handler) CreateDefaultResourceIfNeeded(cfg *v1.Config) (*v1.Config, error) {
 	// assume the caller has call lock on the mutex .. out pattern is to have that as
 	// high up the stack as possible ... loc because need to
@@ -316,7 +342,7 @@ func (h *Handler) CreateDefaultResourceIfNeeded(cfg *v1.Config) (*v1.Config, err
 		cfg.Name = v1.ConfigName
 		cfg.Kind = "Config"
 		cfg.APIVersion = v1.GroupName + "/" + v1.Version
-		cfg.Spec.Architectures = append(cfg.Spec.Architectures, v1.X86Architecture)
+		cfg = h.updateCfgArch(cfg)
 		cfg.Spec.ManagementState = operatorsv1api.Managed
 		h.AddFinalizer(cfg)
 		// we should get a watch event for the default pull secret, but just in case
@@ -551,6 +577,10 @@ func (h *Handler) Handle(event v1.Event) error {
 		// Every time we see a change to the Config object, update the ClusterOperator status
 		// based on the current conditions of the Config.
 		cfg = h.refetchCfgMinimizeConflicts(cfg)
+		//TODO remove this setting of version once we start getting samples for z or ppc
+		if operatorstatus.IsNonX86Arch(cfg) {
+			cfg.Status.Version = h.version
+		}
 		err := h.cvowrapper.UpdateOperatorStatus(cfg, false)
 		if err != nil {
 			logrus.Errorf("error updating cluster operator status: %v", err)
@@ -587,6 +617,12 @@ func (h *Handler) Handle(event v1.Event) error {
 			return h.crdwrapper.UpdateStatus(cfg, dbg)
 		}
 
+		//TODO adjust this check as we start getting samples for z or ppc
+		if operatorstatus.IsNonX86Arch(cfg) {
+			logrus.Printf("samples are not installed on non-x86 architectures")
+			return nil
+		}
+
 		h.buildSkipFilters(cfg)
 		configChanged := false
 		configChangeRequiresUpsert := false
@@ -709,7 +745,7 @@ func (h *Handler) Handle(event v1.Event) error {
 		}
 
 		if len(cfg.Spec.Architectures) == 0 {
-			cfg.Spec.Architectures = append(cfg.Spec.Architectures, v1.X86Architecture)
+			cfg = h.updateCfgArch(cfg)
 		}
 
 		h.StoreCurrentValidConfig(cfg)
@@ -776,10 +812,8 @@ func (h *Handler) Handle(event v1.Event) error {
 			now := kapis.Now()
 			cfg = h.refetchCfgMinimizeConflicts(cfg)
 			progressing := cfg.Condition(v1.ImageChangesInProgress)
-			progressing.LastUpdateTime = now
-			progressing.LastTransitionTime = now
-			logrus.Debugf("Handle changing processing from false to true")
-			progressing.Status = corev1.ConditionTrue
+			progressing.Reason = ""
+			progressing.Message = ""
 			for isName := range h.imagestreamFile {
 				_, skipped := h.skippedImagestreams[isName]
 				unskipping := len(unskippedStreams) > 0
@@ -791,6 +825,34 @@ func (h *Handler) Handle(event v1.Event) error {
 					progressing.Reason = progressing.Reason + isName + " "
 				}
 			}
+			if len(progressing.Reason) > 0 {
+				progressing.LastUpdateTime = now
+				progressing.LastTransitionTime = now
+				logrus.Debugf("Handle changing processing from false to true")
+				progressing.Status = corev1.ConditionTrue
+			} else {
+				logrus.Debugln("there are no imagestreams available for import")
+				// see if there are unskipped templates, to set SamplesExists to true
+				if !cfg.ConditionTrue(v1.SamplesExist) {
+					templatesProcessed := false
+					for tName := range h.templateFile {
+						_, skipped := h.skippedTemplates[tName]
+						if skipped {
+							continue
+						}
+						templatesProcessed = true
+						break
+					}
+					if templatesProcessed {
+						cfg = h.refetchCfgMinimizeConflicts(cfg)
+						h.GoodConditionUpdate(cfg, corev1.ConditionTrue, v1.SamplesExist)
+						dbg := "exist true update templates only"
+						logrus.Printf("CRDUPDATE %s", dbg)
+						return h.crdwrapper.UpdateStatus(cfg, dbg)
+					}
+				}
+				return nil
+			}
 			logrus.Debugf("Handle Reason field set to %s", progressing.Reason)
 			cfg.ConditionUpdate(progressing)
 
